#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITINTEGER_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITINTEGER_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/bitinteger.hpp>

#endif
